Coverage for src/configuraptor/__init__.py: 100%

1"""

2 Exposes TypedConfig and load_into for this library.

3"""

4

5# SPDX-FileCopyrightText: 2023-present Robin van der Noord <robinvandernoord@gmail.com>

6#

7# SPDX-License-Identifier: MIT

8 from .alias import Alias, alias

9 from .binary_config import BinaryConfig, BinaryField

10 from .cls import TypedConfig, TypedMapping, TypedMutableMapping, update

11 from .core import (

12 check_and_convert_data,

13 convert_config,

14 ensure_types,

15 load_data,

16 load_into,

17 load_into_class,

18 load_into_instance,

19)

20 from .dump import asbytes, asdict, asjson, astoml, asyaml

21 from .helpers import all_annotations, check_type

22 from .loaders import register_loader as loader

23 from .postpone import postpone

24 from .singleton import Singleton, SingletonMeta

25 from .type_converters import register_converter as converter

26

27 __all__ = [

28 # binary

29 "BinaryConfig",

30 "BinaryField",

31 # cls

32 "TypedConfig",

33 "TypedMapping",

34 "TypedMutableMapping",

35 "update",

36 # singleton

37 "Singleton",

38 "SingletonMeta",

39 # core

40 "check_and_convert_data",

41 "convert_config",

42 "ensure_types",

43 "load_data",

44 "load_into",

45 "load_into_class",

46 "load_into_instance",

47 # helpers

48 "all_annotations",

49 "check_type",

50 # postpone

51 "postpone",

52 # dump

53 "asbytes",

54 "asdict",

55 "astoml",

56 "asyaml",

57 "asjson",

58 # register

59 "loader",

60 "converter",

61 # alias

62 "alias",

63 "Alias",

64]